#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_fabric_rep_rings
short_description: Resource module for Iot Fabric Rep Rings
description:
  - Manage operation create of the resource Iot Fabric Rep Rings. - > This API configures a REP ring on FABRIC deployment.
    The input payload contains the following fields - ringName unique ring name , rootNetworkDeviceId Network device ID of
    the root node of the REP Ring and rootNeighbourNetworkDeviceIds Network device IDs of the two immediate neighbour devices
    of the root node of the REP Ring. The networkDeviceId is the instanceUuid attribute in the response of API - /dna/intent/api/v1/networkDevices.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deploymentMode:
    description: Deployment mode of the configured REP ring.
    type: str
  ringName:
    description: Unique name of REP ring to be configured.
    type: str
  rootNeighbourNetworkDeviceIds:
    description: It contains the network device IDs of the immediate neighboring ring members of the root node. API `/dna/intent/api/v1/networkDevices`
      can be used to get the list of networkDeviceIds of the neighbors , `instanceUuid` attribute in the response contains
      rootNeighbourNetworkDeviceIds.
    elements: str
    type: list
  rootNetworkDeviceId:
    description: RootNetworkDeviceId is the network device ID of the root node in the REP ring. API `/dna/intent/api/v1/networkDevices`
      can be used to get the rootNetworkDeviceId , `instanceUuid` attribute in the response contains rootNetworkDeviceId.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration ConfigureAREPRingOnFABRICDeployment
    description: Complete reference of the ConfigureAREPRingOnFABRICDeployment API.
    link: https://developer.cisco.com/docs/dna-center/#!configure-arep-ring-on-fabric-deployment
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.configure_a_r_e_p_ring_on_f_a_b_r_i_c_deployment,
  - Paths used are
    post /dna/intent/api/v1/iot/fabric/repRings,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.iot_fabric_rep_rings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deploymentMode: string
    ringName: string
    rootNeighbourNetworkDeviceIds:
      - string
    rootNetworkDeviceId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_intended_layer2_info
short_description: Information module for Wired Network Devices Id Config Features Intended Layer2
description:
  - Get all Wired Network Devices Id Config Features Intended Layer2.
  - This API returns the configurations for the intended layer 2 features on a wired device.
  - Even after the intended configurations are deployed using the deploy API,
    they continue to be a part of the intended features on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Network device ID of the wired device to configure.
    type: str
  feature:
    description:
      - >
        Feature query parameter. Name of the feature to configure. The API
        /data/intent/api/wired/networkDevices/{id}/configFeatures/supported/layer2 can be used to get the list
        of features supported on a device.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired GetConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
    description: Complete reference of the GetConfigurationsForIntendedLayer2FeaturesOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!get-configurations-for-intended-layer-2-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.get_configurations_for_intended_layer2_features_on_a_wired_device,
  - Paths used are
    get /dna/intent/api/v1/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2,
"""

EXAMPLES = r"""
---
- name: Get all Wired Network Devices Id Config Features Intended Layer2
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    feature: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "features": {
          "cdpGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "timer": 0,
                "isCdpEnabled": true,
                "isLogDuplexMismatchEnabled": true,
                "isAdvertiseV2Enabled": true,
                "holdTime": 0
              }
            ]
          },
          "cdpInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "isCdpEnabled": true,
                "isLogDuplexMismatchEnabled": true
              }
            ]
          },
          "dhcpSnoopingGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "isDhcpSnoopingEnabled": true,
                "databaseAgent": {
                  "agentUrl": "string",
                  "timeout": 0,
                  "writeDelay": 0
                },
                "isGleaningEnabled": true,
                "proxyBridgeVlans": "string"
              }
            ]
          },
          "dhcpSnoopingInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "isTrustedInterface": true,
                "interfaceName": "string"
              }
            ]
          },
          "dot1xGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "authenticationConfigMode": "string",
                "isDot1xEnabled": true
              }
            ]
          },
          "dot1xInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "authenticationOrder": {
                  "configType": "string",
                  "items": [
                    "string"
                  ]
                },
                "priority": {
                  "configType": "string",
                  "items": [
                    "string"
                  ]
                },
                "inactivityTimer": 0,
                "authenticationMode": "string",
                "isReauthEnabled": true,
                "maxReauthRequests": 0,
                "isInactivityTimerFromServerEnabled": true,
                "isReauthTimerFromServerEnabled": true,
                "reauthTimer": 0,
                "txPeriod": 0
              }
            ]
          },
          "igmpSnoopingGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "isIgmpSnoopingEnabled": true,
                "isQuerierEnabled": true,
                "querierQueryInterval": 0,
                "querierVersion": "string",
                "igmpSnoopingVlanSettings": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "vlanId": 0,
                      "isIgmpSnoopingEnabled": true,
                      "isImmediateLeaveEnabled": true,
                      "isQuerierEnabled": true,
                      "querierQueryInterval": 0,
                      "igmpSnoopingVlanMrouters": {
                        "configType": "string",
                        "items": [
                          {
                            "configType": "string",
                            "interfaceName": "string"
                          }
                        ]
                      }
                    }
                  ]
                }
              }
            ]
          },
          "lldpGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "timer": 0,
                "isLldpEnabled": true,
                "reinitializationDelay": 0,
                "holdTime": 0
              }
            ]
          },
          "lldpInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "adminStatus": "string"
              }
            ]
          },
          "mabInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "isMabEnabled": true
              }
            ]
          },
          "mldSnoopingGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "isMldSnoopingEnabled": true,
                "isQuerierEnabled": true,
                "querierQueryInterval": 0,
                "querierVersion": "string",
                "mldSnoopingVlanSettings": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "vlanId": 0,
                      "isMldSnoopingEnabled": true,
                      "isImmediateLeaveEnabled": true,
                      "isQuerierEnabled": true,
                      "querierQueryInterval": 0,
                      "mldSnoopingVlanMrouters": {
                        "configType": "string",
                        "items": [
                          "string"
                        ]
                      }
                    }
                  ]
                }
              }
            ]
          },
          "portchannelConfig": {
            "items": [
              {
                "configType": "string",
                "isAutoEnabled": true,
                "loadBalancingMethod": "string",
                "lacpSystemPriority": 0,
                "portchannels": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "name": "string",
                      "isLayer2": true,
                      "memberPorts": {
                        "configType": "string",
                        "items": [
                          "string"
                        ]
                      }
                    }
                  ]
                }
              }
            ]
          },
          "stpGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "stpMode": "string",
                "isBackboneFastEnabled": true,
                "isEtherChannelGuardEnabled": true,
                "isExtendedSystemIdEnabled": true,
                "isLoggingEnabled": true,
                "isLoopGuardEnabled": true,
                "portFastMode": "string",
                "isBpduFilterEnabled": true,
                "isBpduGuardEnabled": true,
                "isUplinkFastEnabled": true,
                "transmitHoldCount": 0,
                "uplinkFastMaxUpdateRate": 0,
                "stpInstances": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "vlanId": 0,
                      "priority": 0,
                      "isStpEnabled": true
                    }
                  ]
                }
              }
            ]
          },
          "stpInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "guardMode": "string",
                "bpduFilter": "string",
                "bpduGuard": "string",
                "pathCost": 0,
                "priority": 0,
                "portVlanCostSettings": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "cost": 0,
                      "vlans": "string"
                    }
                  ]
                },
                "portVlanPrioritySettings": {
                  "configType": "string",
                  "items": [
                    {
                      "configType": "string",
                      "priority": 0,
                      "vlans": "string"
                    }
                  ]
                }
              }
            ]
          },
          "switchportInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "description": "string",
                "mode": "string",
                "accessVlan": 0,
                "adminStatus": "string",
                "trunkAllowedVlans": "string",
                "nativeVlan": 0
              }
            ]
          },
          "trunkInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "isProtected": true,
                "isDtpNegotiationEnabled": true,
                "pruneEligibleVlans": "string"
              }
            ]
          },
          "vlanConfig": {
            "items": [
              {
                "configType": "string",
                "vlanId": 0,
                "name": "string",
                "isVlanEnabled": true
              }
            ]
          },
          "vtpGlobalConfig": {
            "items": [
              {
                "configType": "string",
                "mode": "string",
                "version": "string",
                "isPruningEnabled": true,
                "configurationFileName": "string",
                "sourceInterface": "string"
              }
            ]
          },
          "vtpInterfaceConfig": {
            "items": [
              {
                "configType": "string",
                "interfaceName": "string",
                "isVtpEnabled": true
              }
            ]
          }
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_issues_resolve
short_description: Resource module for Assurance Issues Resolve
description:
  - Manage operation create of the resource Assurance Issues Resolve. - > Resolves the given list of issues. The response
    contains the list of issues which were successfully resolved as well as the issues which are failed to resolve. After
    this API returns success response, it may take few seconds for the issue status to be updated if the system is heavily
    loaded. Please use `GET /dna/data/api/v1/assuranceIssues/{id}` API to fetch the details of a particular issue and verify
    `updatedTime`. For detailed information about the usage of the API, please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api- specs/blob/main/Assurance/CE_Cat_Center_Org-IssuesLifecycle-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  issueIds:
    description: Issue Ids.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Issues ResolveTheGivenListsOfIssues
    description: Complete reference of the ResolveTheGivenListsOfIssues API.
    link: https://developer.cisco.com/docs/dna-center/#!resolve-the-given-lists-of-issues
notes:
  - SDK Method used are
    issues.Issues.resolve_the_given_lists_of_issues,
  - Paths used are
    post /dna/intent/api/v1/assuranceIssues/resolve,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assurance_issues_resolve:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    issueIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "successfulIssueIds": [
          "string"
        ],
        "failureIssueIds": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discoverys_jobs
short_description: Resource module for Discoverys Jobs
description:
  - Manage operation create of the resource Discoverys Jobs. - > This API starts a discovery job using the given discovery
    id. The response includes a task url that provides access to the task's details. By accessing this URL, users will receive
    a response containing a resultLocation attribute, which provides details of the discovery job that was started, including
    the jobId. A new discovery job is created every time this API is triggered.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. The id of the discovery.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices StartsTheExistingDiscovery
    description: Complete reference of the StartsTheExistingDiscovery API.
    link: https://developer.cisco.com/docs/dna-center/#!starts-the-existing-discovery
notes:
  - SDK Method used are
    devices.Devices.starts_the_existing_discovery,
  - Paths used are
    post /dna/intent/api/v1/discoverys/{id}/jobs,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.discoverys_jobs:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assign_to_site_apply
short_description: Resource module for Assign To Site Apply
description:
  - Manage operation create of the resource Assign To Site Apply. - > Assign unprovisioned network devices to a site. Along
    with that it can also be used to assign unprovisioned network devices to a different site. If device controllability is
    enabled, it will be triggered once device assigned to site successfully. Device Controllability can be enabled/disabled
    using `/dna/intent/api/v1/networkDevices/deviceControllability/settings`.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceIds:
    description: Unassigned network devices, ranging from a minimum of 1 to a maximum of 100.
    elements: str
    type: list
  siteId:
    description: This must be building Id or floor Id. Access points, Sensors are assigned to floor. Remaining network devices
      are assigned to building. Site Id can be retrieved using '/intent/api/v1/sites'.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design AssignNetworkDevicesToASite
    description: Complete reference of the AssignNetworkDevicesToASite API.
    link: https://developer.cisco.com/docs/dna-center/#!assign-network-devices-to-a-site
notes:
  - SDK Method used are
    site_design.SiteDesign.assign_network_devices_to_a_site,
  - Paths used are
    post /dna/intent/api/v1/networkDevices/assignToSite/apply,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assign_to_site_apply:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceIds:
      - string
    siteId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_id_distribute
short_description: Resource module for Network Device Images Id Distribute
description:
  - Manage operation create of the resource Network Device Images Id Distribute.
  - This API initiates the process of distributing the software image on the network device.
  - Providing value for the `distributedImages` will only trigger the distribution process.
  - To monitor the progress and completion of the update task, call the GET API
    `/dna/intent/api/v1/networkDeviceImageUpdates?parentId={taskId}`, where `taskId` is from the response.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  distributedImages:
    description: Network Device Images Id Distribute's distributedImages.
    elements: dict
    suboptions:
      id:
        description: Software image identifier.
        type: str
    type: list
  id:
    description: Id path parameter. Network device identifier.
    type: str
  networkValidationIds:
    description: List of unique identifiers of custom network device validations.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) DistributeImagesOnTheNetworkDevice
    description: Complete reference of the DistributeImagesOnTheNetworkDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!distribute-images-on-the-network-device
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.distribute_images_on_the_network_device,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceImages/{id}/distribute,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_images_id_distribute:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    distributedImages:
      - id: string
    id: string
    networkValidationIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: feature_templates_wireless_summary_info
short_description: Information module for Feature Templates Wireless Summary
description:
  - Get all Feature Templates Wireless Summary.
  - This API allows users to retrieve the feature template summary.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  type:
    description:
      - >
        Type query parameter. Feature template name. Allowed values EVENT_DRIVEN_RRM_CONFIGURATION,
        DOT11AX_CONFIGURATION, AAA_RADIUS_ATTRIBUTES_CONFIGURATION, ADVANCED_SSID_CONFIGURATION,
        RRM_FRA_CONFIGURATION, CLEANAIR_CONFIGURATION, DOT11BE_STATUS_CONFIGURATION, FLEX_CONFIGURATION,
        MULTICAST_CONFIGURATION, RRM_GENERAL_CONFIGURATION.
    type: str
  designName:
    description:
      - DesignName query parameter. Feature template design name.
    type: str
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Default is 25 if not specified.
        Maximum allowed limit is 25.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page. The first record is numbered 1.
    type: int
  systemTemplate:
    description:
      - >
        SystemTemplate query parameter. If 'True', it signifies a system-generated template; if 'False', it
        denotes a user-modifiable template.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetFeatureTemplateSummary
    description: Complete reference of the GetFeatureTemplateSummary API.
    link: https://developer.cisco.com/docs/dna-center/#!get-feature-template-summary
notes:
  - SDK Method used are
    wireless.Wireless.get_feature_template_summary,
  - Paths used are
    get /dna/intent/api/v1/featureTemplates/wireless/summary,
"""

EXAMPLES = r"""
---
- name: Get all Feature Templates Wireless Summary
  cisco.dnac.feature_templates_wireless_summary_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    type: string
    designName: string
    limit: 0
    offset: 0
    systemTemplate: true
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "type": "string",
          "count": 0,
          "instances": [
            {
              "designName": "string",
              "id": "string",
              "systemTemplate": true
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_dot11be_profiles_info
short_description: Information module for Wireless Settings Dot11be Profiles
description:
  - Get all Wireless Settings Dot11be Profiles.
  - Get Wireless Settings Dot11be Profiles by id.
  - This API allows the user to get 802.11be Profile by ID.
  - This API allows the user to get 802.11be Profiles configured under Wireless Settings.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
        Maximum allowed limit is 500.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page, the first record is numbered 1.
    type: int
  profileName:
    description:
      - ProfileName query parameter. Profile Name.
    type: str
  isOfDmaDownLink:
    description:
      - IsOfDmaDownLink query parameter. OFDMA Downlink.
    type: bool
  isOfDmaUpLink:
    description:
      - IsOfDmaUpLink query parameter. OFDMA Uplink.
    type: bool
  isMuMimoUpLink:
    description:
      - IsMuMimoUpLink query parameter. MU-MIMO Uplink.
    type: bool
  isMuMimoDownLink:
    description:
      - IsMuMimoDownLink query parameter. MU-MIMO Downlink.
    type: bool
  isOfDmaMultiRu:
    description:
      - IsOfDmaMultiRu query parameter. OFDMA Multi-RU.
    type: bool
  id:
    description:
      - Id path parameter. 802.11be Profile ID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless Get80211beProfileByID
    description: Complete reference of the Get80211beProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!get-80-21-1be-profile-by-id
  - name: Cisco DNA Center documentation for Wireless Get80211beProfiles
    description: Complete reference of the Get80211beProfiles API.
    link: https://developer.cisco.com/docs/dna-center/#!get-80-21-1be-profiles
notes:
  - SDK Method used are
    wireless.Wireless.get80211be_profile_by_id,
    wireless.Wireless.get80211be_profiles,
  - Paths used are
    get /dna/intent/api/v1/wirelessSettings/dot11beProfiles,
    get /dna/intent/api/v1/wirelessSettings/dot11beProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Wireless Settings Dot11be Profiles
  cisco.dnac.wireless_settings_dot11be_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    limit: 0
    offset: 0
    profileName: string
    isOfDmaDownLink: true
    isOfDmaUpLink: true
    isMuMimoUpLink: true
    isMuMimoDownLink: true
    isOfDmaMultiRu: true
  register: result
- name: Get Wireless Settings Dot11be Profiles by id
  cisco.dnac.wireless_settings_dot11be_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "profileName": "string",
        "ofdmaDownLink": true,
        "ofdmaUpLink": true,
        "muMimoDownLink": true,
        "muMimoUpLink": true,
        "ofdmaMultiRu": true,
        "default": true,
        "mloGroup": {
          "primary24GhzEnable": true,
          "primary5GhzEnable": true,
          "secondary5GhzEnable": true,
          "primary6GhzEnable": true
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_config_files_id_download_masked
short_description: Resource module for Network Device Config Files Id Download Masked
description:
  - Manage operation create of the resource Network Device Config Files Id Download Masked.
  - Download the masked sanitized device configuration by providing the file `id`.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. The value of `id` can be obtained from the response of API `/dna/intent/api/v1/networkDeviceConfigFiles`.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Configuration Archive DownloadMaskedDeviceConfiguration
    description: Complete reference of the DownloadMaskedDeviceConfiguration API.
    link: https://developer.cisco.com/docs/dna-center/#!download-masked-device-configuration
notes:
  - SDK Method used are
    configuration_archive.ConfigurationArchive.download_masked_device_configuration,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceConfigFiles/{id}/downloadMasked,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_config_files_id_download_masked:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_not_assigned_to_site_info
short_description: Information module for Network Devices Not Assigned To Site
description:
  - Get all Network Devices Not Assigned To Site.
  - Get network devices that are not assigned to any site.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records to show for this page;The minimum is 1, and the maximum is 500.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design GetSiteNotAssignedNetworkDevices
    description: Complete reference of the GetSiteNotAssignedNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-not-assigned-network-devices
notes:
  - SDK Method used are
    site_design.SiteDesign.get_site_not_assigned_network_devices,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/notAssignedToSite,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Not Assigned To Site
  cisco.dnac.network_devices_not_assigned_to_site_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "deviceIds": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: tags_network_devices_members_associations_bulk
short_description: Resource module for Tags Network Devices Members Associations Bulk
description:
  - Manage operation update of the resource Tags Network Devices Members Associations Bulk. - > Updates the tags associated
    with the devices. A tag is a user-defined or system-defined construct to group resources. When a device is tagged, it
    is called a member of the tag. A tag can be created by using this POST `/dna/intent/api/v1/tag` API.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Tags Network Devices Members Associations Bulk's payload.
    elements: dict
    suboptions:
      id:
        description: Network device id.
        type: str
      tags:
        description: Tags Network Devices Members Associations Bulk's tags.
        elements: dict
        suboptions:
          id:
            description: Tag id.
            type: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Tag UpdateTagsAssociatedWithTheNetworkDevices
    description: Complete reference of the UpdateTagsAssociatedWithTheNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!update-tags-associated-with-the-network-devices
notes:
  - SDK Method used are
    tag.Tag.update_tags_associated_with_the_network_devices,
  - Paths used are
    put /dna/intent/api/v1/tags/networkDevices/membersAssociations/bulk,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.tags_network_devices_members_associations_bulk:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    payload:
      - id: string
        tags:
          - id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: event_subscription_syslog
short_description: Resource module for Event Subscription Syslog
description:
  - Manage operations create and update of the resource Event Subscription Syslog.
  - Create Syslog Subscription Endpoint for list of registered events.
  - Update Syslog Subscription Endpoint for list of registered events.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Event Subscription Syslog's payload.
    elements: dict
    suboptions:
      description:
        description: Description.
        type: str
      filter:
        description: Event Subscription Syslog's filter.
        suboptions:
          categories:
            description: Categories.
            elements: str
            type: list
          domainsSubdomains:
            description: Event Subscription Syslog's domainsSubdomains.
            elements: dict
            suboptions:
              domain:
                description: Domain.
                type: str
              subDomains:
                description: Sub Domains.
                elements: str
                type: list
            type: list
          eventIds:
            description: Event Ids (Comma separated event ids).
            elements: str
            type: list
          severities:
            description: Severities.
            elements: str
            type: list
          siteIds:
            description: Site Ids.
            elements: str
            type: list
          sources:
            description: Sources.
            elements: str
            type: list
          types:
            description: Types.
            elements: str
            type: list
        type: dict
      name:
        description: Name.
        type: str
      subscriptionEndpoints:
        description: Event Subscription Syslog's subscriptionEndpoints.
        elements: dict
        suboptions:
          instanceId:
            description: (From Get Rest/Webhook Subscription Details --> pick instanceId).
            type: str
          subscriptionDetails:
            description: Event Subscription Syslog's subscriptionDetails.
            suboptions:
              connectorType:
                description: Connector Type (Must be REST).
                type: str
            type: dict
        type: list
      subscriptionId:
        description: Subscription Id (Unique UUID).
        type: str
      version:
        description: Version.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Event Management CreateSyslogEventSubscription
    description: Complete reference of the CreateSyslogEventSubscription API.
    link: https://developer.cisco.com/docs/dna-center/#!create-syslog-event-subscription
  - name: Cisco DNA Center documentation for Event Management UpdateSyslogEventSubscription
    description: Complete reference of the UpdateSyslogEventSubscription API.
    link: https://developer.cisco.com/docs/dna-center/#!update-syslog-event-subscription
notes:
  - SDK Method used are
    event_management.EventManagement.create_syslog_event_subscription,
    event_management.EventManagement.update_syslog_event_subscription,
  - Paths used are
    post /dna/intent/api/v1/event/subscription/syslog,
    put /dna/intent/api/v1/event/subscription/syslog,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.event_subscription_syslog:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - description: string
        filter:
          categories:
            - string
          domainsSubdomains:
            - domain: string
              subDomains:
                - string
          eventIds:
            - string
          severities:
            - string
          siteIds:
            - string
          sources:
            - string
          types:
            - string
        name: string
        subscriptionEndpoints:
          - instanceId: string
            subscriptionDetails:
              connectorType: string
        subscriptionId: string
        version: string
- name: Update all
  cisco.dnac.event_subscription_syslog:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - description: string
        filter:
          categories:
            - string
          domainsSubdomains:
            - domain: string
              subDomains:
                - string
          eventIds:
            - string
          severities:
            - string
          siteIds:
            - string
          sources:
            - string
          types:
            - string
        name: string
        subscriptionEndpoints:
          - instanceId: string
            subscriptionDetails:
              connectorType: string
        subscriptionId: string
        version: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "statusUri": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_v2_info
short_description: Information module for Network V2
description:
  - Get all Network V2.
  - API to get SNMP, NTP, Network AAA, Client and Endpoint AAA, and/or DNS center server settings.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - SiteId query parameter. Site Id to get the network settings associated with the site.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Network Settings GetNetworkV2
    description: Complete reference of the GetNetworkV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-v-2
notes:
  - SDK Method used are
    network_settings.NetworkSettings.get_network_v2,
  - Paths used are
    get /dna/intent/api/v2/network,
"""

EXAMPLES = r"""
---
- name: Get all Network V2
  cisco.dnac.network_v2_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "instanceType": "string",
        "instanceUuid": "string",
        "namespace": "string",
        "type": "string",
        "key": "string",
        "version": 0,
        "value": [
          "string"
        ],
        "groupUuid": "string",
        "inheritedGroupUuid": "string",
        "inheritedGroupName": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright: (c) 2017, Dag Wieers <dag@wieers.com>
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

ANSIBLE_METADATA = {"metadata_version": "1.1", "status": ["preview"], "supported_by": "certified"}

DOCUMENTATION = r"""
---
module: aci_aep_to_domain
short_description: Bind AEPs to Physical or Virtual Domains (infra:RsDomP)
description:
- Bind AEPs to Physical or Virtual Domains on Cisco ACI fabrics.
options:
  aep:
    description:
    - The name of the Attachable Access Entity Profile.
    type: str
    aliases: [ aep_name ]
  domain:
    description:
    - Name of the physical or virtual domain being associated with the AEP.
    type: str
    aliases: [ domain_name, domain_profile ]
  domain_type:
    description:
    - Determines if the Domain is physical (phys) or virtual (vmm).
    type: str
    choices: [ fc, l2dom, l3dom, phys, vmm ]
    aliases: [ type ]
  state:
    description:
    - Use C(present) or C(absent) for adding or removing.
    - Use C(query) for listing an object or multiple objects.
    type: str
    choices: [ absent, present, query ]
    default: present
  vm_provider:
    description:
    - The VM platform for VMM Domains.
    - Support for Kubernetes was added in ACI v3.0.
    - Support for CloudFoundry, OpenShift and Red Hat was added in ACI v3.1.
    type: str
    choices: [ cloudfoundry, kubernetes, microsoft, openshift, openstack, redhat, vmware, nutanix ]
extends_documentation_fragment:
- cisco.aci.aci
- cisco.aci.annotation

notes:
- The C(aep) and C(domain) parameters should exist before using this module.
  The M(cisco.aci.aci_aep) and M(cisco.aci.aci_domain) can be used for these.
seealso:
- module: cisco.aci.aci_aep
- module: cisco.aci.aci_domain
- name: APIC Management Information Model reference
  description: More information about the internal APIC class B(infra:RsDomP).
  link: https://developer.cisco.com/docs/apic-mim-ref/
author:
- Dag Wieers (@dagwieers)
"""

EXAMPLES = r"""
- name: Add AEP to domain binding
  cisco.aci.aci_aep_to_domain: &binding_present
    host: apic
    username: admin
    password: SomeSecretPassword
    aep: test_aep
    domain: phys_dom
    domain_type: phys
    state: present
  delegate_to: localhost

- name: Remove AEP to domain binding
  cisco.aci.aci_aep_to_domain: &binding_absent
    host: apic
    username: admin
    password: SomeSecretPassword
    aep: test_aep
    domain: phys_dom
    domain_type: phys
    state: absent
  delegate_to: localhost

- name: Query our AEP to domain binding
  cisco.aci.aci_aep_to_domain:
    host: apic
    username: admin
    password: SomeSecretPassword
    aep: test_aep
    domain: phys_dom
    domain_type: phys
    state: query
  delegate_to: localhost
  register: query_result

- name: Query all AEP to domain bindings
  cisco.aci.aci_aep_to_domain: &binding_query
    host: apic
    username: admin
    password: SomeSecretPassword
    state: query
  delegate_to: localhost
  register: query_result
"""

RETURN = r"""
current:
  description: The existing configuration from the APIC after the module has finished
  returned: success
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production environment",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
error:
  description: The error information as returned from the APIC
  returned: failure
  type: dict
  sample:
    {
        "code": "122",
        "text": "unknown managed object class foo"
    }
raw:
  description: The raw output returned by the APIC REST API (xml or json)
  returned: parse error
  type: str
  sample: '<?xml version="1.0" encoding="UTF-8"?><imdata totalCount="1"><error code="122" text="unknown managed object class foo"/></imdata>'
sent:
  description: The actual/minimal configuration pushed to the APIC
  returned: info
  type: list
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment"
            }
        }
    }
previous:
  description: The original configuration from the APIC before the module has started
  returned: info
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
proposed:
  description: The assembled configuration from the user-provided parameters
  returned: info
  type: dict
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment",
                "name": "production"
            }
        }
    }
filter_string:
  description: The filter string used for the request
  returned: failure or debug
  type: str
  sample: ?rsp-prop-include=config-only
method:
  description: The HTTP method used for the request to the APIC
  returned: failure or debug
  type: str
  sample: POST
response:
  description: The HTTP response from the APIC
  returned: failure or debug
  type: str
  sample: OK (30 bytes)
status:
  description: The HTTP status from the APIC
  returned: failure or debug
  type: int
  sample: 200
url:
  description: The HTTP url used for the request to the APIC
  returned: failure or debug
  type: str
  sample: https://10.11.12.13/api/mo/uni/tn-production.json
"""

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.cisco.aci.plugins.module_utils.aci import ACIModule, aci_argument_spec, aci_annotation_spec
from ansible_collections.cisco.aci.plugins.module_utils.constants import VM_PROVIDER_MAPPING


def main():
    argument_spec = aci_argument_spec()
    argument_spec.update(aci_annotation_spec())
    argument_spec.update(
        aep=dict(type="str", aliases=["aep_name"]),  # Not required for querying all objects
        domain=dict(type="str", aliases=["domain_name", "domain_profile"]),  # Not required for querying all objects
        domain_type=dict(type="str", choices=["fc", "l2dom", "l3dom", "phys", "vmm"], aliases=["type"]),  # Not required for querying all objects
        state=dict(type="str", default="present", choices=["absent", "present", "query"]),
        vm_provider=dict(type="str", choices=list(VM_PROVIDER_MAPPING)),
    )

    module = AnsibleModule(
        argument_spec=argument_spec,
        supports_check_mode=True,
        required_if=[
            ["domain_type", "vmm", ["vm_provider"]],
            ["state", "absent", ["aep", "domain", "domain_type"]],
            ["state", "present", ["aep", "domain", "domain_type"]],
        ],
        required_together=[
            ["domain", "domain_type"],
        ],
    )

    aep = module.params.get("aep")
    domain = module.params.get("domain")
    domain_type = module.params.get("domain_type")
    vm_provider = module.params.get("vm_provider")
    state = module.params.get("state")

    # Report when vm_provider is set when type is not virtual
    if domain_type != "vmm" and vm_provider is not None:
        module.fail_json(msg="Domain type '{0}' cannot have a 'vm_provider'".format(domain_type))

    # Compile the full domain for URL building
    if domain_type == "fc":
        domain_mo = "uni/fc-{0}".format(domain)
    elif domain_type == "l2dom":
        domain_mo = "uni/l2dom-{0}".format(domain)
    elif domain_type == "l3dom":
        domain_mo = "uni/l3dom-{0}".format(domain)
    elif domain_type == "phys":
        domain_mo = "uni/phys-{0}".format(domain)
    elif domain_type == "vmm":
        domain_mo = "uni/vmmp-{0}/dom-{1}".format(VM_PROVIDER_MAPPING[vm_provider], domain)
    else:
        domain_mo = None

    aci = ACIModule(module)
    aci.construct_url(
        root_class=dict(
            aci_class="infraAttEntityP",
            aci_rn="infra/attentp-{0}".format(aep),
            module_object=aep,
            target_filter={"name": aep},
        ),
        subclass_1=dict(
            aci_class="infraRsDomP",
            aci_rn="rsdomP-[{0}]".format(domain_mo),
            module_object=domain_mo,
            target_filter={"tDn": domain_mo},
        ),
    )

    aci.get_existing()

    if state == "present":
        aci.payload(
            aci_class="infraRsDomP",
            class_config=dict(tDn=domain_mo),
        )

        aci.get_diff(aci_class="infraRsDomP")

        aci.post_config()

    elif state == "absent":
        aci.delete_config()

    aci.exit_json()


if __name__ == "__main__":
    main()
